@@ -119,6 +119,9 @@ FAILEDOPERATION_MODIFYROGROUPERROR = 'FailedOperation.ModifyROGroupError'
 # 不符合资源所拥有的网络数量要求。
 FAILEDOPERATION_NETWORKNUMLIMITERROR = 'FailedOperation.NetworkNumLimitError'
 
+# 实例无可用备机
+FAILEDOPERATION_NOAVAILABLESTANDBY = 'FailedOperation.NoAvailableStandby'
+
 # 操作超过频率限制，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_OPERATEFREQUENCYLIMITEDERROR = 'FailedOperation.OperateFrequencyLimitedError'
 
@@ -134,6 +137,9 @@ FAILEDOPERATION_PAYORDERFAILED = 'FailedOperation.PayOrderFailed'
 # 按量计费实例账户解冻结失败，请稍后重试。如果持续不成功，请联系客服进行处理。
 FAILEDOPERATION_POSTPAIDUNBLOCKERROR = 'FailedOperation.PostPaidUnblockError'
 
+# 操作预检查失败。
+FAILEDOPERATION_PRECHECKERROR = 'FailedOperation.PreCheckError'
+
 # 获取预签名授权URL错误。
 FAILEDOPERATION_PRESIGNEDURLGETERROR = 'FailedOperation.PresignedURLGetError'
 
@@ -251,6 +257,9 @@ INTERNALERROR_INSTANCEDATAERROR = 'InternalError.InstanceDataError'
 # 请求执行异常。
 INTERNALERROR_INTERNALHTTPSERVERERROR = 'InternalError.InternalHttpServerError'
 
+# Json数据解析失败，请联系客服进行处理。
+INTERNALERROR_JSONPARSEERROR = 'InternalError.JsonParseError'
+
 # 后台数据解析失败，请联系客服进行处理。
 INTERNALERROR_MARSHALERROR = 'InternalError.MarshalError'
 
@@ -284,6 +293,9 @@ INVALIDPARAMETER_INSTANCENAMEEXIST = 'InvalidParameter.InstanceNameExist'
 # 参数检查失败。
 INVALIDPARAMETER_PARAMETERCHECKERROR = 'InvalidParameter.ParameterCheckError'
 
+# 参数不可全部不设置
+INVALIDPARAMETER_PARAMETERSNOTSET = 'InvalidParameter.ParametersNotSet'
+
 # pid错误。
 INVALIDPARAMETER_TRADEACCESSDENIEDERROR = 'InvalidParameter.TradeAccessDeniedError'
 
@@ -311,6 +323,9 @@ INVALIDPARAMETERVALUE_CHARSETNOTFOUNDERROR = 'InvalidParameterValue.CharsetNotFo
 # 数据格式转换失败，请联系客服处理。
 INVALIDPARAMETERVALUE_DATACONVERTERROR = 'InvalidParameterValue.DataConvertError'
 
+# 解密密码失败，请确认密码加密是否正确。
+INVALIDPARAMETERVALUE_DECRYPTPASSWORDFAILED = 'InvalidParameterValue.DecryptPasswordFailed'
+
 # 不支持的计费类型。
 INVALIDPARAMETERVALUE_ILLEGALCHARGETYPE = 'InvalidParameterValue.IllegalChargeType'
 
@@ -344,9 +359,21 @@ INVALIDPARAMETERVALUE_INVALIDACCOUNTFORMAT = 'InvalidParameterValue.InvalidAccou
 # 当前账号名称不允许是保留字符。
 INVALIDPARAMETERVALUE_INVALIDACCOUNTNAME = 'InvalidParameterValue.InvalidAccountName'
 
+# 账号设置无效，请遵循账号命名规则：账号名需要1-16个字符，只能由字母、数字或下划线组成；不能为postgres；不能由数字、pg_及tencentdb_开头；所有规则均不区分大小写。
+INVALIDPARAMETERVALUE_INVALIDACCOUNTNAMEERROR = 'InvalidParameterValue.InvalidAccountNameError'
+
+# 账号无效，请遵循账号命名规则：由字母（a-z, A-Z）、数字（0-9）、下划线（_）组成，以字母或（_）开头，最多63个字符。不能使用系统保留关键字，不能为postgres，且不能由pg_或tencentdb_开头。
+INVALIDPARAMETERVALUE_INVALIDACCOUNTNAMEFORMATERROR = 'InvalidParameterValue.InvalidAccountNameFormatError'
+
 # 数据库字符集错误，当前只支持UTF8、LATIN1。
 INVALIDPARAMETERVALUE_INVALIDCHARSET = 'InvalidParameterValue.InvalidCharset'
 
+# 数据库名称无效，请遵循命名规则：由字母（a-z, A-Z）、数字（0-9）、下划线（_）组成，以字母或（_）开头，最多63个字符。不能使用系统保留关键字。
+INVALIDPARAMETERVALUE_INVALIDDATABASENAMEFORMATERROR = 'InvalidParameterValue.InvalidDatabaseNameFormatError'
+
+# 当前仅支持操作名称为英文、下划线、数字及特殊符号[]组成的数据库对象，函数及存储过程额外支持三个特殊符号(,)
+INVALIDPARAMETERVALUE_INVALIDDATABASEOBJECTNAME = 'InvalidParameterValue.InvalidDatabaseObjectName'
+
 # 购买实例数超过限制。
 INVALIDPARAMETERVALUE_INVALIDINSTANCENUM = 'InvalidParameterValue.InvalidInstanceNum'
 
@@ -389,15 +416,15 @@ INVALIDPARAMETERVALUE_PARAMETERCHARACTERERROR = 'InvalidParameterValue.Parameter
 # 参数不满足规则，请修改后重试。
 INVALIDPARAMETERVALUE_PARAMETERCHARACTERLIMITERROR = 'InvalidParameterValue.ParameterCharacterLimitError'
 
-# 参数前缀设置不符合规则要求，请修改后重试。
-INVALIDPARAMETERVALUE_PARAMETERCHARACTERPRELIMITERROR = 'InvalidParameterValue.ParameterCharacterPreLimitError'
-
 # 参数处理失败，请检参数值设置是否有效。
 INVALIDPARAMETERVALUE_PARAMETERHANDLEERROR = 'InvalidParameterValue.ParameterHandleError'
 
 # 参数长度超过限制。
 INVALIDPARAMETERVALUE_PARAMETERLENGTHLIMITERROR = 'InvalidParameterValue.ParameterLengthLimitError'
 
+# 参数超出可设置范围
+INVALIDPARAMETERVALUE_PARAMETEROUTOFRANGE = 'InvalidParameterValue.ParameterOutOfRange'
+
 # 存在无效的参数值。
 INVALIDPARAMETERVALUE_PARAMETEROUTRANGEERROR = 'InvalidParameterValue.ParameterOutRangeError'
 
@@ -449,6 +476,15 @@ OPERATIONDENIED_INSTANCESTATUSLIMITERROR = 'OperationDenied.InstanceStatusLimitE
 # 实例状态限制当前操作。
 OPERATIONDENIED_INSTANCESTATUSLIMITOPERROR = 'OperationDenied.InstanceStatusLimitOpError'
 
+# 实例类型错误
+OPERATIONDENIED_INSTANCETYPEDENIED = 'OperationDenied.InstanceTypeDenied'
+
+# 账号余额不足。
+OPERATIONDENIED_INSUFFICIENTBALANCEERROR = 'OperationDenied.InsufficientBalanceError'
+
+# 内核版本过低，导致实例无法创建tencentDBSuper账号。如果您想使用此功能，请升级内核版本。
+OPERATIONDENIED_KERNELVERSIONERROR = 'OperationDenied.KernelVersionError'
+
 # Serverless不支持当前可用区。
 OPERATIONDENIED_NOTSUPPORTZONEERROR = 'OperationDenied.NotSupportZoneError'
 
@@ -470,6 +506,9 @@ OPERATIONDENIED_ROINSTANCESTATUSLIMITOPERROR = 'OperationDenied.ROInstanceStatus
 # 只读节点总数不能超过上限值。
 OPERATIONDENIED_ROINSTANCECOUNTEXEEDERROR = 'OperationDenied.RoInstanceCountExeedError'
 
+# 无支付权限，开通失败。
+OPERATIONDENIED_TRADEPERMISSIONERROR = 'OperationDenied.TradePermissionError'
+
 # 用户未进行实名认证，请先进行实名认证才可购买。
 OPERATIONDENIED_USERNOTAUTHENTICATEDERROR = 'OperationDenied.UserNotAuthenticatedError'
 
